$set 14 #main

$ #RCRequiresArg
# kda: '-rc' nepiecieams arguments\n
$ #DISPLAYRequiresArg
# kda: '-display' nepiecieams arguments\n
$ #WarnDisplaySet
# brdinjums: nevarju iestatt vides maingo 'DISPLAY'\n
$ #Usage
# Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
  -display <virkne>\t\tlietot displeja savienojumu.\n\
  -rc <virkne>\t\t\tlietot citu resersu failu.\n\
  -version\t\t\tpardt versiju un iziet.\n\
  -info\t\t\t\tdisplay some useful information.\n\
  -log <filename>\t\t\tlog output to file.\n\
  -help\t\t\t\tpardt o paldzbas tekstu un iziet.\n\n
$ #CompileOptions
# Kompilcijas laika opcijas:\n\
  Atkdoana\t\t\t%s\n\
  Rindprlces izvrse:\t\t\t%s\n\
  Veidne:\t\t\t%s\n\
  lums:\t\t\t\t%s\n\
  8bpp Pakpes Tonana:\t%s\n\n
